***
<H1 align="center">Semantyk</H1>
<p align="center">
  <i>– Ideas Wonder –</i><br><br>
  <img src="https://raw.githubusercontent.com/semantykcom/Semantyk/master/docs/Semantyk.png" alt="Semantyk" width="250"/><br><br>
  <b>Author: Daniel Bakas Amuchástegui</b><br>
  August 31, 2017<br>
  <i>Copyright © 2020 Semantyk. All rights reserved.</i>
</p>

***
